/**
 * 限制输入框
 * type：
 *  price >= 0 && 小数限制  // 开单价钱
 *  amount > 0 && 小数限制 // 开单数量
 *  amount-zero 数量小数限制 可以是零
 */
Vue.directive('verify', {
    inserted: function (el,binding) {
        let oldValue = { value: ''}
        switch (binding.arg) {
            case 'price': price(el,oldValue); break;
            case 'amount': amount(el,oldValue); break;
            case 'amount-zero': amount(el,oldValue, true); break;
        }
    }
})
const _VerifyCache = {}
function Rule (input){
    this.input = input
}
Rule.prototype={
    // 补零
    zeroPadding(length) {
        this.input = String(Number(this.input))
        let decimalIndex = this.input.indexOf('.')
        let decimalLength = (decimalIndex === -1 ? this.input.length: decimalIndex) + length + 1 //添加小数后的目标长度
        let addLength = decimalLength - this.input.length
        // 有小数点 小数目标长度大于当前长度 补零
        if(decimalIndex !== -1 && decimalLength > this.input.length){
            for(;addLength > 0; addLength--) {
                this.input += '0'
            }
            return this
        }
        // 有小数点 小数目标长度小于当前长度 返回
        if(decimalIndex !== -1 && decimalLength < this.input.length) {
            return this
        }
        // 有小数点 小数目标长度等于当前长度
        if(decimalIndex !== -1 && decimalLength === this.input.length) {
            return this
        }
        // 无小数点 需要补领
        this.input += '.'
        addLength--
        for(;addLength > 0; addLength--) {
            this.input += '0'
        }
        return this
    },
    // 非数字替换为''
    notANumber(){
        this.input = this.input.replace(/[^\d\.]/g, '')
        return this
    },
    // 保证第一个为数字
    numberStart(){
        this.input = this.input.replace(/^\./g,'')
        return this
    },
    // 没有多个.
    repeatDecimal(){
        this.input = this.input.replace(/\.{2,}/g,'.')
        return this
    },
    // 小数长度限制
    decimalLength(length){
        const reg =new RegExp("(\\-)*(\\d+)\\.(\\d{"+ length+ "}).*$")
        this.input = this.input.replace(reg, '$1$2.$3')
        return this
    },
    // 不能是零
    notZero(be){
        if(Number(this.input) === 0){
            this.input = be || 1
        }
        return this
    },
    // 不能为空
    notSpace(be){
        if (this.input === ''){
            this.input = be || '0'
        }
        return this
    }
}



//开单价钱 price >= 0 && 小数限制
function price(el,oldValue) {
    bindFocusSaveOldValue(el,oldValue)
    el.addEventListener('input', function (e){
        if(e.$inputType === 'blur-input'){return}
        let value = e.currentTarget.value
        let decimalLength = JSON.parse(localStorage.getItem('systemSetting')).price_decimals_setting
        if(!decimalLength && decimalLength !== 0){decimalLength = 2}
        const rule = new Rule(value)
        el.value = rule.notANumber().numberStart().repeatDecimal().decimalLength(decimalLength).input
        value !== el.value && el.dispatchEvent(new Event('input'))
    })
    el.addEventListener('blur', function (e){
        let value = e.currentTarget.value
        let decimalLength = JSON.parse(localStorage.getItem('systemSetting')).price_decimals_setting
        if(!decimalLength && decimalLength !== 0){decimalLength = 2}
        const rule = new Rule(value )
        el.value = rule.notSpace(oldValue.value).notANumber().numberStart().repeatDecimal().decimalLength(decimalLength).zeroPadding(2).input // 价格 不足2位 补足2位
        value !== el.value && el.dispatchEvent((function(){
            let e = new Event('input')
            e.$inputType = 'blur-input'
            return e
        })())
    })
}
// 数量
function amount(el,oldValue, canBeZero) {
    bindFocusSaveOldValue(el,oldValue)
    el.addEventListener('input', function (e){
        let value = e.currentTarget.value
        let decimalLength = JSON.parse(localStorage.getItem('systemSetting')).amount_decimals_setting
        const rule = new Rule(value)
        el.value = rule.notANumber().numberStart().repeatDecimal().decimalLength(decimalLength).input
        value !== el.value && el.dispatchEvent(new Event('input'))
    })
    el.addEventListener('blur', function (e){
        let value = e.currentTarget.value
        let decimalLength = JSON.parse(localStorage.getItem('systemSetting')).amount_decimals_setting
        const rule = new Rule(value)
        if(canBeZero){
            el.value = rule.notSpace(oldValue.value).notANumber().numberStart().repeatDecimal().decimalLength(decimalLength).input
        }else{
            el.value = rule.notSpace(oldValue.value).notANumber().numberStart().repeatDecimal().notZero('1').decimalLength(decimalLength).input
        }
        delete el.dataset.oldValue
        value !== el.value && el.dispatchEvent(new Event('input'))
    })
}
// 存储旧值到dom上 并 置空
function bindFocusSaveOldValue(el,oldValue){
    el.addEventListener('focus', function(){
        oldValue.value = el.value
        el.value = ''
    })
}
