const JumpPage = {
    /**
     * 跳转页面 注意在回调中向打开的页面传递数据时 plusReady 的触发时机有可能早于该回调事件 Webview窗口显示动画执行完毕时触发回调函数
     * @param {string} url 要显示Webview窗口路径
     * @param {string} aniShow 动画效果
     * @param {string} id 要显示Webview窗口id
     * @param {number} duration 显示Webview窗口动画的持续时间
     * @param {function} cbFn 回调函数
     * @param {object} arg 可携带参数 {} // 打开的页面通过  plus.webview.currentWebview().arg 获取数据
     **/
    jump(url, id, cbFn ,aniShow = 'slide-in-right', duration = 200, arg = {}) {
        plus.key.hideSoftKeybord();
        function callBack() {
            cbFn&&cbFn()
            userHtml && userHtml.evalJS("window.defaultParameters&&defaultParameters()")
        }
        let extras = {}
        extras.arg = JSON.stringify(arg)
        let userHtml = plus.webview.getWebviewById(id); //查找view是否存在
        if (!userHtml) {
            plus.webview.create(
                url,
                id, {
                    height:'100%',
                    // popGesture: 'close'
                }, extras); //后台创建webview Page
        }
        // 打开页面
        plus.webview.show(id, aniShow, duration, callBack) // 参数5 Webview窗口扩展参数 extras https://www.html5plus.org/doc/zh_cn/webview.html#plus.webview.WebviewExtraOptions
    },

    /**
    * 页面预加载
    * @param {string} url 动画效果
    * @param {string} id 要显示Webview窗口id
    * @param {object} extras 可携带参数 {arg：{...}} // 打开的页面通过  plus.webview.currentWebview().arg 获取数据
    **/
    preloading(url, id, extras= {}) {
        let userHtml = plus.webview.getWebviewById(id); //查找view是否存在
        if(userHtml) {
            return userHtml
        }
        return plus.webview.create(
            url,
            id, {
                height:'100%',
                // popGesture: 'close'
            }, extras)
    }
}
const Location = {
    /**
     *  获取当前页面URL参数 单个key值
     * @param variable key
     * @return {string|boolean}
     */
    getQueryVariable(variable)
        {
            let query = window.location.search.substring(1);
            let vars = query.split("&");
            for (let i=0;i<vars.length;i++) {
                let pair = vars[i].split("=");
                if(pair[0] == variable){return pair[1];}
            }
            return(false);
        }
}