/**
 * 打印数据工具
 * printUtil.print('type',[ids],{options}).then().catch()
 * 打印条码 需要跳到数量选择页 -> 获取图片 -> 打印
 */
(function(){

    const TYPE = {
        // 标签
        'label':'label',
        // SN
        'SN': 'SN',
        // 单据
        'invoice':'invoice'
    }
    const INVOICE_TYPE = {
        // 历史
        'history':0,
        // 订单
        'draft': 1,
        // 撤销
        'revoke':2,
    }

    /**
     *
     * @constructor
     */
    function CreatePrintUtil(){
        this.systemSetting = JSON.parse(localStorage.getItem('systemSetting'))
        this.userInfo = JSON.parse(localStorage.getItem('user_info'))
        this.size_show = localStorage.getItem("size_show") || 1
        this.color_show = localStorage.getItem("color_show") || 1
        this.unit_show = localStorage.getItem("unit_show") || 0
        this.origin_specification = localStorage.getItem("origin_specification") || 0

    }
    CreatePrintUtil.prototype = {
        /**
         * 查询打印权限
         */
        qryPrintPurview(){
           return new Promise(function(resolve, reject) {
               $API.user.qryCompany().then(function(e){
                   if(e.data.status != 1){
                       reject({type: 'success',data: {msg: '没有打印权限'}})
                   }else{
                       resolve(e)
                   }
               })
           })
        },
        /**
         * 打印
         * @param type 标签（序列号，条码）还是单据
         * @param ids   单据id 或 标签 数组
         * @param options
         * @return {Promise<unknown>}
         */
        print: function (type, ids, options){
            let _this = this
            if(type === TYPE.label){
                return _this.startTask(type, ids, options)
            }
            return new Promise(function(resolve, reject){
                _this.qryPrintPurview().then(function(e){
                    _this.startTask(type, ids, options).then(function(){
                       resolve()
                   })
                }).catch(function(e) {
                    if (e.type !== 'success') {
                        mui.toast('网络异常')
                    }else if(e.data.msg === '没有打印权限'){
                        $comm.showLimitPrint({rootPath:'./'})// 没有打印权限时
                    }else{
                        mui.toast(e.data.msg)
                    }
                    reject(e)
                })
            })
        },
        /**
         * 跳转打印标签页
         * @param type 标签（条码）
         * @param ids   单据id
         * @param options
         * @return {Promise<unknown>}
         */
        jump: function (type, ids, options){
            let _this = this
            if(type === TYPE.label){
                return _this.jumpPage(type, ids, options)
            }
        },
        /**
         * 开始一个打印任务
         */
        startTask: function (type, ids, options){
            let _this = this
            if(type === TYPE.invoice){
                let id = ids[0]
                return _this.getOrderData(id).then(function(e){
                    let data = e.data
                    return _this.formDataInvoice(data)
                }).then(function(data){
                    data = formatDataPrint(data)
                    $API.print.modifyPrintStatus({id: id}).catch(function(){mui.toast('打印状态修改失败！')})
                    if (mui.os.ios === true) {
                        receiptPrint_i(data, options.purchaseManager)
                        return Promise.resolve()
                    } else if (mui.os.android === true) {
                        printBill(data, options.purchaseManager)
                        return Promise.resolve()
                    }
                })
            }
            if(type === TYPE.SN){
                return {}
            }
            if(type === TYPE.label){
                return {}
            }
        },
        /**
         * 跳转到打印选择页面
         * @param type
         * @param ids
         * @param options
         * @return {*}
         */
        jumpPage: function (type, ids, options){
            let _this = this
            if(type === TYPE.label){
                let id = ids[0]
                let _ids = []
                let productList = []
                return _this.getOrderLabel(id).then(function(e){
                    productList = e.data.productlist;
                    let checkedList = [],qry_index = 0,qry_list = [];
                    productList.forEach(function(i){
                        if(!_ids.includes(i.product_id)){
                            _ids.push(i.product_id)
                        }
                    })
                    if(_ids.length === 0){
                        return Promise.reject({msg: '没有可打印的商品'})
                    }else{
                        return _this.getProductOtherAttr(_ids)
                    }
                }).then(function(e){
                    let data = []
                    let i = 0
                    productList.forEach(function(target){
                        let attrs = e.data.filter(function(_item){return target.product_id === _item.product_id})
                        data.push({
                            "barcode": target.barcode,
                            "color": target.color_name,
                            "color_id": target.color_id,
                            "index": i + "",
                            "product_id":target.product_id,
                            "model": target.product_model,
                            "name": target.product_name,
                            "num": Number(target.amount).toFixed(0),
                            "size": target.size_name,
                            "size_id": target.size_id,
                            "material": target.material,
                            "otherAttrList": attrs || [],
                            "sale_price":target.sale_price_a,
                            "sale_price_a":target.sale_price_a,
                            "sale_price_b":target.sale_price_b,
                            'keyList':options.keyList || []
                        })
                    })

                    let k = 0;
                    let msg = "";
                    for (var j = 0; j < data.length; j++) {
                        if (data[j].barcode == "") {
                            msg += "货号:" + data[j].model + "  颜色:" + data[j].color + "  尺码:" + data[j].size + "\n";
                            k++;
                        }
                        if(k > 17){
                            msg +="......\n"
                            break;
                        }
                    }
                    msg += "请前往商品信息页面设置\n";
                    sessionStorage.setItem("checkedList", JSON.stringify(data));
                    if (k != 0) {
                        return Promise.reject({msg: msg, title: '还有商品未设置条码'})
                    } else {
                        viewHandle.openWindow( 'printCode.html','printCode.html',JSON.stringify({checkedList: data}));
                        return Promise.resolve()
                    }
                })
            }
        },
        // 查询一个单据
        getOrderData: function(id){
            return $API.order.queryOrderInfo({id: id})
        },
        // 查询单据序列号:
        getOrderLabel: function(id){
            return $API.order.qryOpWithBarcode({id: id})
        },
        // 查询打印商品其他属性
        getProductOtherAttr: function(ids){
            return $API.print.getProductOtherAttr({product_ids: ids.join(';')})
        },
        // 查询顾客
        getCustomerInfo: function(customerId) {
            return $API.user.getCustomer({id: customerId})
        },
        /**
         * 处理票据数据
         * @param data
         * @return {Promise<unknown>}
         */
        formDataInvoice: function(data){
            let _this = this
            let truePay = data.org_debt_amt != '' ? Number(data.order_amt - data.org_debt_amt) : Number(data.order_amt - data.debt_amt);
            if (truePay >= 0) {
                truePay = numToCur(Number(truePay - data.rebate_amt - (data.discount || 0) - (data.deduction_amt || 0)),_this.systemSetting.price_decimals_setting,'price')
            } else {
                truePay = numToCur(Number(truePay + data.rebate_amt + (data.discount || 0) - (data.deduction_amt || 0)),_this.systemSetting.price_decimals_setting,'price')
            }
            data.truePay = truePay

            mui.each(data.productlist, function(i, v) {
                v.unitChooseId = v.display_unit_id;
                v.unitChooseName = v.display_unit_name;
                v.unitChooseRatio = v.display_unit_ratio;
                v.desc = v.description
            });
            let deliveryCompanyList = [{"delivery_company":"JD","name":"京东快递"},{"delivery_company":"JDKY","name":"京东快运"},{"delivery_company":"NSF","name":"新顺丰"},{"delivery_company":"SF","name":"顺丰速运"},{"delivery_company":"SFGJ","name":"顺丰国际"},{"delivery_company":"YTO","name":"圆通速递"},{"delivery_company":"YTOGJ","name":"圆通国际"},{"delivery_company":"ZTO","name":"中通快递"},{"delivery_company":"ZTOKY","name":"中通快运"},{"delivery_company":"STO","name":"申通快递"},{"delivery_company":"STO_INTL","name":"申通快递国际单"},{"delivery_company":"YD","name":"韵达速递"},{"delivery_company":"YDKY","name":"韵达快运"},{"delivery_company":"DBL","name":"德邦快递"},{"delivery_company":"DBLKY","name":"德邦快运"},{"delivery_company":"OTHERS","name":"其他"}]
            let deliveryCompany = deliveryCompanyList.find(function(i){
                return i.delivery_company === data.delivery_company
            })
            let deliveryCompanyStr = deliveryCompany ? deliveryCompany.name : ''

            data.change_interal = data.changeinteral
            data.real_name = data.creater_name
            data.telePhone = data.telephone
            data.print_address = data.consignee_address
            data.company_name = _this.userInfo.company_name
            data.size_show = _this.size_show
            data.color_show = _this.color_show
            data.unit_show = _this.unit_show
            data.origin_specification = _this.origin_specification
            data.is_check_customer = data.is_check_customer === '1'
            data.delivery_company_name = deliveryCompanyStr

            let depotList = JSON.parse(localStorage.getItem("depotList"));
            data.depot_name = depotList.find(function(i){return i.id === data.depot_id}).name
            if(data.submit_status === INVOICE_TYPE.draft){
                data.account_name = ''
                data.purchase_amt = 0
                data.sign_date = ''
            }
            return new Promise(function(resolve){
                _this.getCustomerInfo(data.customer_id).then(function(e){
                    data.totalDebtAmt = e.data.customer.arrears
                    resolve(data)
                })
            })
        },
        /**
         * 处理标签数据
         * @param data
         * @return {Promise<unknown>}
         */
        formDataLabel: function(data){
            let _this = this

        }

    }
    // 暴露接口
    this.$class || (this.$class = {})
    this.$class.CreatePrintUtil = CreatePrintUtil

    function formatDataPrint(order){
        const productList = order.productlist
        let i = 0
        productList.forEach(function(product){
            if(product.is_extra === 1){
                i++
                const span = '(' + i + ')'
                product.product_id += span
                product.product_model += span
                product.product_name += span
            }
        })
        return JSON.stringify(order)
    }

})()


