var slider = new Vue({
	el: '#slider',
	data: {
		// image1: 'https://img0.baidu.com/it/u=2090383909,3765764187&fm=11&fmt=auto&gp=0.jpg', // 大图
		image1:undefined,
		image2: undefined, // 小图
		mouseDown: false, // 鼠标是否在按钮上按下
		startWidth: 50, // 鼠标点下去时父级的width
		startX: 0, // 鼠标按下时的X
		newX: 0, // 鼠标当前的偏移X
		loading: true, // 是否正在加载中，主要是等图片onload
		isCanSlide: false, // 是否可以拉动滑动条
		error: false, // 图片加在失败会出现这个，提示用户手动刷新
		infoBoxShow: false, // 提示信息是否出现
		infoText: '', // 提示等信息
		infoBoxFail: false, // 是否验证失败
		timer1: null, // setTimout1
		closeDown: false, // 为了解决Mac上的click BUG
		isSuccess: false, // 验证成功
		// resetSvg:require('@reset.png'),
		isSubmit: false, // 是否正在验证中,
		id: undefined,
		canvasWidth: 280, // 主canvas的宽
		canvasHeight: 150, // 主canvas的高
		// 是否出现，由父级控制
		show: false,
		sliderSize: 35, // 滑块的大小
		successText: '验证成功！',
		failText: '验证失败，请重试',
		sliderText: '拖动滑块完成拼图',
		borderRadius: 10,
		codeId: '',
		requestBack:true
	},
	/** 计算属性 **/
	computed: {
		// styleWidth是底部用户操作的滑块的父级，就是轨道在鼠标的作用下应该具有的宽度
		styleWidth() {
			const w = this.startWidth + this.newX - this.startX
			let W =
				w < this.sliderBaseSize ?
				this.sliderBaseSize :
				w > this.canvasWidth ?
				this.canvasWidth :
				w
			return W
		},
		// 处理一下sliderSize，弄成整数，以免计算有偏差
		sliderBaseSize() {
			return Math.max(
				Math.min(
					Math.round(this.sliderSize),
					Math.round(this.canvasWidth * 0.5)
				),
				10
			)
		}
	},

	/** 监听 **/
	watch: {
		show(newV) {
			// 每次出现都应该重新初始化
			if (newV) {
				document.body.classList.add('vue-puzzle-overflow')
				this.reset()
			} else {
				document.body.classList.remove('vue-puzzle-overflow')
			}
		}
	},

	/** 生命周期 **/
	mounted() {
		// document.body.appendChild(this.$el)
		// console.log(this.$el) 
		// 初始化
		this.infoText = ''
		this.infoBoxFail = false
		this.infoBoxShow = false
		this.isCanSlide = true
		this.isSuccess = false
		this.startWidth = this.sliderBaseSize // 鼠标点下去时父级的width
		this.startX = 0 // 鼠标按下时的X
		this.newX = 0 // 鼠标当前的偏移X
	},
	beforeDestroy() {
		clearTimeout(this.timer1)
		this.image1 = undefined
		this.image2 = undefined
	},
	methods: {
		// 关闭
		onClose() {
			if (!this.mouseDown) {
				clearTimeout(this.timer1)
				this.$emit('update:show', false)
				this.$emit('close')
			}
		},
		onCloseMouseDown() {
			this.closeDown = true
		},
		onCloseMouseUp() {
			if (this.closeDown) {
				this.onClose()
			}
			this.closeDown = false
		},
		// 鼠标按下准备拖动
		onRangeMouseDown(e) {
			console.log('onRangeMouseDown')
			// mousemove touchmove
			document.addEventListener('touchmove', this.onRangeMouseMove, false)
			if (this.isCanSlide) {
				this.mouseDown = true
				this.startWidth = this.$refs['range-slider'].clientWidth
				this.newX = e.clientX || e.changedTouches[0].clientX
				this.startX = e.clientX || e.changedTouches[0].clientX
			}
		},
		// 鼠标移动
		onRangeMouseMove(e) {
			// console.log('onRangeMouseMove')
			// console.log(this.mouseDown)
			if (this.mouseDown) {
				if(!slider.loading){
				// e.preventDefault()
				this.newX = e.clientX || e.changedTouches[0].clientX
				// console.log(this.newX)
				let left = this.styleWidth - this.sliderBaseSize
				$('.auth-canvas2_').css('left', left)
				}
			}
		},
		// 鼠标抬起
		onRangeMouseUp() {
			console.log('onRangeMouseUp');
			document.removeEventListener('mousemove', this.onRangeMouseMove, false)
			if (this.mouseDown) {
				this.mouseDown = false
				if(!slider.loading){
					this.submit()
				}
			}
		},
		// *
		//  * 开始进行

		init() {
			this.loading = true
			// this.isCanSlide = false
			this.isCanSlide = true
			console.log(severUrl)
			let data = {}
			if (slider.codeId != '') {
				data = {
					codeId: slider.codeId,
					unionId:loginVM.unionId
				}
			} else {
				data = {
					codeId: '',
					unionId:loginVM.unionId
				}
			}
			mui.ajax({
				url: severUrl + 'ValidCode/jpgs',
				data: data,
				type: 'GET',
				dataType: "json",
				xhrFields: {
					withCredentials: true
				},
				crossDomain: true, //crossDomain设置为true，强制使用5+跨域
				success: function(res) {
					if (res.status==200) {
						slider.image1 = res.data.image1
						slider.image2 = res.data.image2
						slider.loading = false
						slider.isCanSlide = true
						slider.startTime = new Date().getTime()
						slider.codeId = res.data.codeId
						$('.auth-canvas2_').css('top',res.data.y)
					}else{
						mui.toast(res.msg)
						$('#slider').css('display','none')
						// 禁用按钮
						$("#loginBtn").attr('disabled','disabled')
						// 一分钟后放开禁用按钮
						setTimeout(function(){
							$(".loginBtn").attr('disabled',false)
						},60000)
					}
				}
			})
			console.log(slider.codeId)
		},
		// 开始判定
		submit() {
			// 关闭拖动
			this.isCanSlide = false
			this.isSubmit = true
			const x = Math.floor(this.newX - this.startX)+10
			console.log(this.newX,this.startX,x)
			this.loading = true
			let _this = this
			mui.ajax(severUrl + "login", {
				data: {
					userno: loginVM.userno,
					pwd: doRSAEncrypt(loginVM.pwd),
					validCode: loginVM.validCode,
					autoLogin: loginVM.autoLogin,
					is_phone: 1, 
					codeId: slider.codeId,
					aesCode: getAES(x + ';' + slider.canvasWidth),
					token: loginVM.loginToken,
				}, 
				dataType: 'json', //服务器返回json格式数据
				type: 'post', //HTTP请求类型
				xhrFields: {
					withCredentials: true
				},
				crossDomain: true, //crossDomain设置为true，强制使用5+跨域
				// timeout: 10000, //超时时间设置为10秒；
				success:function(data){
					if(data.success){
						slider.infoBoxShow=true
						slider.infoText=slider.successText
						slider.loading=false
						localStorage.setItem("HF",data.data.accessToken);
						var screenH=window.screen.availHeight;
						var screenW=window.screen.availWidth;
						var bootStatus=localStorage.getItem("bootStatus");
						setTimeout(function(){
							if(screenH < screenW || bootStatus === '1'){
								viewHandle.viewFire('H576E5848','login')
								viewHandle.openWindow('H576E5848','H576E5848')
							}else{
								viewHandle.openWindow('view/leadPage.html','leadPage.html')
							}
							closeMy()
						},1000)
						function closeMy() {
							setTimeout(function(){
								plus.webview.hide('login.html','none')
								plus.webview.close('login.html','none')
							},1000)

						}
					}else{
						if(data.msg.includes('用户滞留页面时间太久')){
							// 如果token过期
							mui.ajax(severUrl + 'preIndex',{
							    data : {
									codeId:''
								},
							    type : 'GET',
							    dataType : "json",
							    success : function(res) {
									console.log(res)
							        if (res.success) {
							            loginVM.loginToken=res.data.token
										loginVM.unionId=res.data.unionId
										slider.submit()
							        } else {
							           mui.toast(res.msg);
							        }
							    }
							})						
						}else{
							mui.toast(data.msg);
							_this.reset()
							$('.auth-canvas2_').css('left', '0')
							$('#slider').css('display','none')
						} 
					}
				}
			});

		},
		// 重置
		reset() {
			console.log('reset')
			this.infoText = ''
			this.infoBoxFail = false
			this.infoBoxShow = false
			this.isCanSlide = true
			this.isSuccess = false
			this.startWidth = this.sliderBaseSize // 鼠标点下去时父级的width
			this.startX = 0 // 鼠标按下时的X
			this.newX = 0 // 鼠标当前的偏移X
			this.init()
		},
		// 取消
		cancel() {
			console.log('cancel')
			this.infoText = ''
			this.infoBoxFail = false
			this.infoBoxShow = false
			this.isCanSlide = true
			this.isSuccess = false
			this.startWidth = this.sliderBaseSize // 鼠标点下去时父级的width
			this.startX = 0 // 鼠标按下时的X
			this.newX = 0 // 鼠标当前的偏移X
			// this.init()
			this.loading=true
			$('#slider').css('display', 'none') 
		}
	}
})
